@@ -1,5 +1,3 @@
-#![forbid(unsafe_code)]
-
 /// Convert a byte slice into a string.
 /// Includes printable ASCII characters as-is.
 /// Converts non-printable or non-ASCII characters to strings like "\n" and "\x19".
@@ -21,6 +19,8 @@
 /// );
 /// assert_eq!("\\x01\\x02\\x03", escape_ascii(&[1, 2, 3]));
 /// ```
+#[must_use]
+#[allow(clippy::missing_panics_doc)]
 pub fn escape_ascii(input: &[u8]) -> String {
     let mut result = String::new();
     for byte in input {
@@ -30,16 +30,3 @@ pub fn escape_ascii(input: &[u8]) -> String {
     }
     result
 }
-
-#[cfg(test)]
-#[test]
-fn test_escape_ascii() {
-    assert_eq!("", escape_ascii(b""));
-    assert_eq!("abc", escape_ascii(b"abc"));
-    assert_eq!("\\r\\n", escape_ascii(b"\r\n"));
-    assert_eq!(
-        "\\xe2\\x82\\xac",
-        escape_ascii(/* Euro sign */ "\u{20AC}".as_bytes())
-    );
-    assert_eq!("\\x01", escape_ascii(b"\x01"));
-}
