@@ -28,26 +28,18 @@
 //! ```rust
 //! # struct Request {}
 //! # impl Request {
-//! #     pub fn parse(line_bytes: &[u8]
-//! #     ) -> Result<Request, std::io::Error> {
+//! #     pub fn parse(line_bytes: &[u8]) -> Result<Request, std::io::Error> {
 //! #         Ok(Request{})
 //! #     }
 //! # }
-//! use fixed_buffer::{
-//!     deframe_line, FixedBuf, ReadWriteChain};
-//! use std::io::{Error, Read, Write};
+//! # fn handle_request(request: Request) -> Result<(), std::io::Error> {
+//! #     Ok(())
+//! # }
+//! use fixed_buffer::{deframe_line, FixedBuf};
+//! use std::io::Error;
 //! use std::net::TcpStream;
 //!
-//! fn handle_request<RW: Read + Write>(
-//!     reader_writer: &mut RW,
-//!     request: Request,
-//! ) -> Result<(), Error> {
-//!     // ...
-//!     Ok(())
-//! }
-//!
-//! fn handle_conn(mut tcp_stream: TcpStream
-//! ) -> Result<(), Error> {
+//! fn handle_conn(mut tcp_stream: TcpStream) -> Result<(), Error> {
 //!     let mut buf: FixedBuf<4096> = FixedBuf::new();
 //!     loop {
 //!         // Read a line
@@ -58,11 +50,7 @@
 //!                 None => return Ok(()),
 //!             };
 //!         let request = Request::parse(line_bytes)?;
-//!         // Read any request payload
-//!         // from `buf` + `TcpStream`.
-//!         let mut reader_writer = ReadWriteChain::new(
-//!             &mut buf, &mut tcp_stream);
-//!         handle_request(&mut reader_writer, request)?;
+//!         handle_request(request)?;
 //!     }
 //! }
 //! ```
@@ -87,8 +75,7 @@
 //!     }
 //! }
 //!
-//! fn read_and_process<R: Read>(mut input: R)
-//!     -> Result<(), Error> {
+//! fn read_and_process<R: Read>(mut input: R) -> Result<(), Error> {
 //!     let mut buf: FixedBuf<1024> = FixedBuf::new();
 //!     loop {
 //!         // Read a chunk into the buffer.
@@ -104,12 +91,12 @@
 //!         }
 //!         // Process records in the buffer.
 //!         loop {
-//!             let bytes_read =
+//!             let num_to_consume =
 //!                 try_process_record(buf.readable())?;
-//!             if bytes_read == 0 {
+//!             if num_to_consume == 0 {
 //!                 break;
 //!             }
-//!             buf.try_read_exact(bytes_read).unwrap();
+//!             buf.try_read_exact(num_to_consume).unwrap();
 //!         }
 //!         // Shift data in the buffer to free up
 //!         // space at the end for writing.
@@ -140,6 +127,8 @@
 //! - [`arrayvec`](https://crates.io/crates/arrayvec), vector with fixed capacity.
 //!
 //! # Changelog
+//! - v0.5.0 - Move `ReadWriteChain` and `ReadWriteTake` to new
+//!   [`read-write-ext`](https://crates.io/crates/read-write-ext) crate.
 //! - v0.4.0
 //!   - `From<&[u8]>`
 //!   - `write_bytes` to take `AsRef<[u8]>`
@@ -206,10 +195,8 @@
 //! </details>
 //!
 //! # TO DO
-//! - Move `ReadWriteChain` and `ReadWriteTake` to a separate crate.
 //! - Change links in docs to standard style.  Don't link to `docs.rs`.
 //! - Idea: `buf.slice(buf.read_frame(&mut reader, deframe_crlf))`
-//! - Implement async-std read & write traits
 //! - Add an `frame_copy_iter` function.
 //!   Because of borrowing rules, this function must return non-borrowed (allocated and copied) data.
 //! - Set up CI on:
@@ -254,12 +241,6 @@ pub use deframe_crlf::deframe_crlf;
 mod deframe_line;
 pub use deframe_line::deframe_line;
 
-mod read_write_chain;
-pub use read_write_chain::*;
-
-mod read_write_take;
-pub use read_write_take::*;
-
 #[cfg(feature = "futures-io")]
 mod impl_futures_io;
 #[cfg(feature = "futures-io")]
@@ -710,8 +691,7 @@ impl<const SIZE: usize> FixedBuf<SIZE> {
     /// let mut input = std::io::Cursor::new(b"aaa\r\nbbb\n\nccc\n");
     /// # let mut output: Vec<String> = Vec::new();
     /// loop {
-    ///   if let Some(line) =
-    ///       buf.read_frame(&mut input, deframe_line).unwrap() {
+    ///   if let Some(line) = buf.read_frame(&mut input, deframe_line).unwrap() {
     ///     println!("{}", escape_ascii(line));
     /// #   output.push(escape_ascii(line));
     ///   } else {
