@@ -16,7 +16,8 @@
 #![forbid(unsafe_code)]
 
 use crc::Hasher32;
-use fixed_buffer::{FixedBuf, ReadWriteChain, ReadWriteTake};
+use fixed_buffer::FixedBuf;
+use read_write_ext::ReadWriteExt;
 use std::io::{ErrorKind, Read, Write};
 use std::net::{Shutdown, SocketAddr, TcpListener, TcpStream};
 use std::println;
@@ -37,12 +38,9 @@ impl<'a, T: Hasher32> Write for Hasher32Writer<'a, T> {
     }
 }
 
-fn handle_crc32<RW: Read + Write>(
-    mut read_writer: &mut RW,
-    len: usize,
-) -> Result<(), std::io::Error> {
+fn handle_crc32<RW: Read + Write>(read_writer: &mut RW, len: usize) -> Result<(), std::io::Error> {
     let mut digest = crc::crc32::Digest::new(crc::crc32::IEEE);
-    let mut payload = ReadWriteTake::new(&mut read_writer, len);
+    let mut payload = read_writer.take_rw(len);
     std::io::copy(&mut payload, &mut Hasher32Writer(&mut digest))?;
     let response = format!("{:x}\n", digest.sum32());
     read_writer.write_all(response.as_bytes())
@@ -87,7 +85,7 @@ fn handle_conn(mut tcp_stream: TcpStream) -> Result<(), std::io::Error> {
         match Request::parse(line_bytes) {
             Some(Request::Hello) => handle_hello(&mut tcp_stream)?,
             Some(Request::Crc32(len)) => {
-                let mut read_writer = ReadWriteChain::new(&mut buf, &mut tcp_stream);
+                let mut read_writer = tcp_stream.chain_after(&mut buf);
                 handle_crc32(&mut read_writer, len)?;
             }
             _ => tcp_stream.write_all("ERROR\n".as_bytes())?,
